<p align="center">
<img src="assets/icon.png" width="200"  alt="">
</p>

## shuangchentools

封装了一些常用的工具

1. doc_segment：文档分割，包括根据标题规则
2. spider：封装常用爬虫工具，包括selenium自动获取cookies、隐藏特征
3. utils：各类工具函数，包括阿拉伯数字转中文

#### 安装

```bash
git clone git@github.com:wangtao2001/sctools.git
cd sctools
pip install -e .
```

或

```bash
pip install shuangchentools
```
